==> amarok-1.83.tar.bz2: amarok-1.83/src/playlist/DynamicTrackNavigator.h <==
/***************************************************************************
 * copyright            : (C) 2008 Daniel Jones <danielcjones@gmail.com> 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/


#ifndef DYNAMICTRACKNAVIGATOR_H
#define DYNAMICTRACKNAVIGATOR_H

#include "DynamicPlaylist.h"
#include "PlaylistModel.h"
#include "TrackNavigator.h"


namespace Playlist {

class Model;

    class DynamicTrackNavigator : public QObject, public TrackNavigator
    {
        Q_OBJECT

        public:
            DynamicTrackNavigator( Model* m, Dynamic::DynamicPlaylistPtr p ) ;
            ~DynamicTrackNavigator();
            int nextRow();
            int lastRow();
            
            void appendUpcoming();

        private slots:
            void activeRowChanged( int from, int to );
            void activeRowExplicitlyChanged( int from, int to );
            void repopulate();

        private:
            void setAsUpcoming( int row );
            void setAsPlayed( int row );
            void markPlayed();

            void removePlayed();


            Dynamic::DynamicPlaylistPtr m_playlist;
    };
}


#endif

==> amarok-1.86.tar.bz2: amarok-1.86/src/playlist/DynamicTrackNavigator.h <==
/***************************************************************************
 * copyright            : (C) 2008 Daniel Jones <danielcjones@gmail.com> 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy 
 * defined in Section 14 of version 3 of the license.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/


#ifndef DYNAMICTRACKNAVIGATOR_H
#define DYNAMICTRACKNAVIGATOR_H

#include "DynamicPlaylist.h"
#include "PlaylistModel.h"
#include "TrackNavigator.h"

#include <QMutex>


namespace Playlist {

class Model;

    class DynamicTrackNavigator : public TrackNavigator
    {
        Q_OBJECT

        public:
            DynamicTrackNavigator( Model* m, Dynamic::DynamicPlaylistPtr p ) ;
            ~DynamicTrackNavigator();
            int nextRow();
            int lastRow();
            
            void appendUpcoming();

        private slots:
            void activeRowChanged( int from, int to );
            void repopulate();

        private:
            void setAsUpcoming( int row );
            void setAsPlayed( int row );
            void markPlayed();

            void removePlayed();
            
            bool m_abortRequested;

            Dynamic::DynamicPlaylistPtr m_playlist;

            QMutex m_mutex;
    };
}


#endif
